//
//  GFaAddAreaInformationViewController.m
//
//  Copyright (c) 2014 ZENRIN DataCom CO., LTD. All Rights Reserved.
//

#import "GFaAddAreaInformationViewController.h"

#import <libGeoFenceManager/GeoFenceManager.h>
#import "GFaUtility.h"

/* フィールド定数定義 */
enum {
    Field_aid = 0,  /* エリアID */
    Field_pinf,     /* ポリゴン情報 */
    Field_lat,      /* 中心緯度 */
    Field_lon,      /* 中心経度 */
    Field_rad,      /* 半径(m) */
    Field_inlv,     /* IN精度閾値 */
    Field_infnum,   /* IN確定回数閾値 */
    Field_outlv,    /* OUT精度閾値 */
    Field_outfnum,  /* OUT確定回数閾値 */
    Field_vst,      /* 有効期間(開始) */
    Field_vet       /* 有効期間(終了) */
};

@interface GFaAddAreaInformationViewController ()

- (UITextField *)findTextField_:(NSInteger)row;
- (void)pushAddButton_;
- (NSDictionary *)inputedToDictionary_;

@end

@implementation GFaAddAreaInformationViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.title = @"エリア情報追加";
    
    UIBarButtonItem *buttonItem = [[UIBarButtonItem alloc] initWithTitle:@"追加"
                                                                   style:UIBarButtonItemStylePlain
                                                                  target:self
                                                                  action:@selector(pushAddButton_)];
    self.navigationItem.rightBarButtonItem = buttonItem;

    UIBarButtonItem *backBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"戻る"
                                                                          style:UIBarButtonItemStylePlain
                                                                         target:self
                                                                         action:nil];
    self.navigationController.navigationBar.topItem.backBarButtonItem = backBarButtonItem;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
}

#pragma mark UITableViewDelegate

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];

    __block UITextField *textField = [self findTextField_:indexPath.row];

    if (textField != nil)
    {
        [GFaUtility showInputAlert:self title:textField.accessibilityLabel message:@"" text:textField.text cancelButtonTitle:@"キャンセル" otherButtonTitle:@"確定" keyboardType:textField.keyboardType otherHandler:^(NSString *value) {
            textField.text = value;
        }];
    }
}

#pragma mark Private

/* 入力フィールド取得 */
- (UITextField *)findTextField_:(NSInteger)row
{
    switch (row) {
        case Field_aid:
            return self.aidTextField;
        case Field_pinf:
            return self.pinfTextField;
        case Field_lat:
            return self.latTextField;
        case Field_lon:
            return self.lonTextField;
        case Field_rad:
            return self.radTextField;
        case Field_inlv:
            return self.inlvTextField;
        case Field_infnum:
            return self.infnumTextField;
        case Field_outlv:
            return self.outlvTextField;
        case Field_outfnum:
            return self.outfnumTextField;
        case Field_vst:
            return self.vstTextField;
        case Field_vet:
            return self.vetTextField;
        default:
            break;
    }
    return nil;
}

- (void)pushAddButton_
{
    GeoFenceManager *manager = [GeoFenceManager defaultManager];
    NSDictionary *setInfo = [self inputedToDictionary_];
    if ( setInfo == nil ) return;
    
    NSArray *array = [manager addAreaInformation:@[setInfo]];
    NSString *title = nil;
    NSString *mess = nil;
    if ( array != nil && array.count == 0 ) {
        title = @"追加成功";
    } else {
        title = @"追加失敗";
    }
    [GFaUtility showInformationAlert:self title:title message:mess];
}

- (NSDictionary *)inputedToDictionary_
{
    // セットするKeyと値
    NSDictionary *info = @{
        GFlResponseKeyAid:self.aidTextField,
        GFlResponseKeyPinf:self.pinfTextField,
        GFlResponseKeyLat:self.latTextField,
        GFlResponseKeyLon:self.lonTextField,
        GFlResponseKeyRad:self.radTextField,
        GFlResponseKeyInlv:self.inlvTextField,
        GFlResponseKeyInfnum:self.infnumTextField,
        GFlResponseKeyOutlv:self.outlvTextField,
        GFlResponseKeyOutfnum:self.outfnumTextField,
        GFlResponseKeyVst:self.vstTextField,
        GFlResponseKeyVet:self.vetTextField,
    };
    
    // NSNumberにするもの
    NSArray *integerKeys = @[
        GFlResponseKeyRad,
        GFlResponseKeyInlv,
        GFlResponseKeyInfnum,
        GFlResponseKeyOutlv,
        GFlResponseKeyOutfnum,
    ];
    
    // NSNumber(double)にするもの
    NSArray *doubleKeys = @[
        GFlResponseKeyLat,
        GFlResponseKeyLon,
    ];
    
    // NSDateにするもの
    NSArray *dateKeys = @[
        GFlResponseKeyVst,
        GFlResponseKeyVet,
    ];
    
    NSMutableDictionary *retInfo = [NSMutableDictionary dictionary];
    for ( NSString *key in info ) {
        UITextField *textField = [info objectForKey:key];
        NSString *str = textField.text;
        if ( str.length > 0 ) {
            if ( [integerKeys containsObject:key] == YES ) {
                NSNumber *setNum = [NSNumber numberWithInt:(int)[str integerValue]];
                if ( setNum != nil ) {
                    [retInfo setObject:setNum forKey:key];
                }
            } else if ( [doubleKeys containsObject:key] == YES ) {
                NSNumber *setNum = [NSNumber numberWithDouble:[str doubleValue]];
                if ( setNum != nil ) {
                    [retInfo setObject:setNum forKey:key];
                }
            } else if ( [dateKeys containsObject:key] == YES ) {
                NSDate *date = [GFaUtility dateFromFormatFromServer:str];
                if ( date != nil ){
                    [retInfo setObject:date forKey:key];
                } else {
                    [GFaUtility showInformationAlert:self title:@"Dateフォーマットエラー" message:@"yyyyMMddHHmmで指定して下さい"];
                    return nil;
                }
            } else {
                [retInfo setObject:str forKey:key];
            }
        }
    }
    return retInfo;
}


@end
