//
//  GFaAddNotificationConditionTableViewController.m
//
//  Copyright (c) 2014 ZENRIN DataCom CO., LTD. All Rights Reserved.
//

#import "GFaAddNotificationConditionTableViewController.h"
#import <libGeoFenceManager/GeoFenceManager.h>
#import "GFaUtility.h"

/* フィールド定数定義 */
enum {
    Field_nid = 0,  /* 通知条件ID */
    Field_aid,      /* エリアID */
    Field_ntmg,     /* 通知タイミング */
    Field_nwk,      /* 通知曜日 */
    Field_nstm,     /* 通知開始時間 */
    Field_netm,     /* 通知終了時間 */
    Field_nsvd,     /* 通知開始期間 */
    Field_nevd,     /* 通知終了期間 */
    Field_notnd     /* 再通知禁止日数 */
};

@interface GFaAddNotificationConditionTableViewController ()

- (UITextField *)findTextField_:(NSInteger)row;
- (void)pushAddButton_;
- (NSDictionary *)inputedToDictionary_;

@end

@implementation GFaAddNotificationConditionTableViewController

- (id)initWithStyle:(UITableViewStyle)style
{
    self = [super initWithStyle:style];
    if (self) {
        // Custom initialization
    }
    return self;
}

- (void)viewDidLoad
{
    [super viewDidLoad];

    self.title = @"通知条件追加";
    
    UIBarButtonItem *buttonItem = [[UIBarButtonItem alloc] initWithTitle:@"追加"
                                                                   style:UIBarButtonItemStylePlain
                                                                  target:self
                                                                  action:@selector(pushAddButton_)];
    self.navigationItem.rightBarButtonItem = buttonItem;

    UIBarButtonItem *backBarButtonItem = [[UIBarButtonItem alloc] initWithTitle:@"戻る"
                                                                          style:UIBarButtonItemStylePlain
                                                                         target:self
                                                                         action:nil];
    self.navigationController.navigationBar.topItem.backBarButtonItem = backBarButtonItem;
}

- (void)didReceiveMemoryWarning
{
    [super didReceiveMemoryWarning];
    // Dispose of any resources that can be recreated.
}

#pragma mark UITableViewDelegate

-(void)tableView:(UITableView *)tableView didSelectRowAtIndexPath:(NSIndexPath *)indexPath
{
    [tableView deselectRowAtIndexPath:indexPath animated:YES];

    __block UITextField *textField = [self findTextField_:indexPath.row];

    if (textField != nil)
    {
        [GFaUtility showInputAlert:self title:textField.accessibilityLabel message:@"" text:textField.text cancelButtonTitle:@"キャンセル" otherButtonTitle:@"確定" keyboardType:textField.keyboardType otherHandler:^(NSString *value) {
            textField.text = value;
        }];
    }
}

#pragma mark Private

/* 入力フィールド取得 */
- (UITextField *)findTextField_:(NSInteger)row
{
    switch (row) {
        case Field_nid:
            return self.nidTextField;
        case Field_aid:
            return self.aidTextField;
        case Field_ntmg:
            return self.ntmgTextField;
        case Field_nwk:
            return self.nwkTextField;
        case Field_nstm:
            return self.nstmTextField;
        case Field_netm:
            return self.netmTextField;
        case Field_nsvd:
            return self.nsvdTextField;
        case Field_nevd:
            return self.nevdTextField;
        case Field_notnd:
            return self.notndTextField;
        default:
            break;
    }
    return nil;
}

- (void)pushAddButton_
{
    GeoFenceManager *manager = [GeoFenceManager defaultManager];
    
    NSDictionary *setInfo = [self inputedToDictionary_];
    if ( setInfo == nil ) return;
    
    NSArray *array = [manager addNotificationConditionInformation:@[setInfo]];
    NSString *title = nil;
    NSString *mess = nil;
    
    if ( array != nil
        && array.count == 0 )
    {
        title = @"追加成功";
    }
    else
    {
        title = @"追加失敗";
    }
    
    [GFaUtility showInformationAlert:self title:title message:mess];
}

- (NSDictionary *)inputedToDictionary_
{
    // セットするKeyと値
    NSDictionary *info = @{
        GFlResponseKeyNid:self.nidTextField,
        GFlResponseKeyAid:self.aidTextField,
        GFlResponseKeyNtmg:self.ntmgTextField,
        GFlResponseKeyNwk:self.nwkTextField,
        GFlResponseKeyNstm:self.nstmTextField,
        GFlResponseKeyNetm:self.netmTextField,
        GFlResponseKeyNsvd:self.nsvdTextField,
        GFlResponseKeyNevd:self.nevdTextField,
        GFlResponseKeyNotnd:self.notndTextField,
    };
    
    // NSNumberにするもの
    NSArray *integerKeys = @[
        GFlResponseKeyNid,
        GFlResponseKeyNtmg,
    ];
    
    // NSDateにするもの
    NSArray *dateKeys = @[
        GFlResponseKeyNsvd,
        GFlResponseKeyNevd,
    ];
    
    NSMutableDictionary *retInfo = [NSMutableDictionary dictionary];
    for ( NSString *key in info )
    {
        UITextField *textField = [info objectForKey:key];
        
        NSString *str = textField.text;
        if ( str.length > 0 )
        {
            if ( [integerKeys containsObject:key] == YES )
            {
                NSNumber *setNum = [NSNumber numberWithInt:(int)[str integerValue]];
                if ( setNum != nil )
                {
                    [retInfo setObject:setNum forKey:key];
                }
            }
            else if ( [dateKeys containsObject:key] == YES )
            {
                NSDate *date = [GFaUtility dateFromFormatFromServer:str];
                if ( date != nil )
                {
                    [retInfo setObject:date forKey:key];
                }
                else
                {
                    [GFaUtility showInformationAlert:self title:@"Dateフォーマットエラー" message:@"yyyyMMddHHmmで指定して下さい"];
                    return nil;
                }
            }
            else
            {
                [retInfo setObject:str forKey:key];
            }
        }
    }
    
    return retInfo;
}

@end

